@@ -1,7 +1,7 @@
 package App::wdq;
 use v5.14;
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.3.1';
 
 1;
 __END__
@@ -53,9 +53,17 @@ Get a documented list of all command line options:
 
 Pass a (possibly abbreviated) SPARQL query via STDIN or option C<--query>.
 
+  wdq < queryfile
+  wdq -q query-or-queryfile
+
 =head2 lookup mode
 
-Pass a line-separated list of Wikidata identifiers or Wikimedia project URLs.
+Pass a line-separated list of Wikidata identifiers or Wikimedia project URLs
+via STDIN or command line arguments:
+
+  wdq Q1
+  wdq lookup Q1
+  echo Q1 | wdq lookup
  
 =head1 EXAMPLES
 
@@ -77,11 +85,11 @@ Pass a line-separated list of Wikidata identifiers or Wikimedia project URLs.
   # print result as Markdown Table (requires Catmandu::Exporter::Table)
   wdq --export Table < query
 
-  # look up label and description 
-  echo Q1 | wdq lookup
+  # look up label and description
+  wdq Q42 P9
 
   # look up German Wikipedia article and get label description in French
-  echo http://de.wikipedia.org/wiki/Argon | wdq lookup -g fr
+  wdq -g fr http://de.wikipedia.org/wiki/Argon 
 
 =head1 COPYRIGHT AND LICENSE
 
